@@ -1,17 +1,24 @@
-import sys
 import re
 import requests
 import json
 
-
-if sys.version_info >= (3, ):
-    import urllib.parse as urlparse
-else:
-    import urlparse
+try:
+    import urlparse  # py2
+except:
+    import urllib.parse as urlparse  # py3
 
 
 from .utils import import_by_path
-from .settings import EMBED_VIDEO_BACKENDS
+from .settings import EMBED_VIDEO_BACKENDS, EMBED_VIDEO_CACHE, \
+                      EMBED_VIDEO_CACHE_TIMEOUT
+
+cache = None
+if EMBED_VIDEO_CACHE:
+    from django.core.cache import cache
+
+
+class VideoDoesntExistException(Exception):
+    pass
 
 
 class UnknownBackendException(Exception):
@@ -70,8 +77,36 @@ class VideoBackend(object):
     """
 
     def __init__(self, url):
-        self._url = url
+        """
+        First it tries to load data from cache and if it don't succeed, run
+        :py:meth:`init` and then save it to cache.
+        """
+        if not self._restore_cache(url):
+            self.init(url)
+            self._set_cache(url)
 
+    def _restore_cache(self, url):
+        """
+        Restore data from cache if cache is enabled.
+        """
+        if cache:
+            data = cache.get(url)
+            if data:
+                self.__dict__ = data
+                return True
+
+    def _set_cache(self, url):
+        """
+        Set data to cache if cache is enabled.
+        """
+        if cache:
+            cache.set(url, self.__dict__)
+
+    def init(self, url):
+        """
+        Load all data (:py:meth:`get_code`, :py:meth:`get_url` etc.)
+        """
+        self._url = url
         self.backend = self.__class__.__name__
         self.code = self.get_code()
         self.url = self.get_url()
@@ -126,7 +161,7 @@ class YoutubeBackend(VideoBackend):
             (\S*[^\w\-\s])?
             (?P<code>[\w\-]{11})[a-z0-9;:@?&%=+/\$_.-]*  # match and extract
         ''',
-        re.I|re.X
+        re.I | re.X
     )
 
     pattern_url = 'http://www.youtube.com/embed/%s?wmode=opaque'
@@ -137,7 +172,11 @@ class YoutubeBackend(VideoBackend):
 
         if not code:
             parse_data = urlparse.urlparse(self._url)
-            code = urlparse.parse_qs(parse_data.query)['v'][0]
+
+            try:
+                code = urlparse.parse_qs(parse_data.query)['v'][0]
+            except KeyError:
+                raise UnknownIdException
 
         return code
 
@@ -151,9 +190,26 @@ class VimeoBackend(VideoBackend):
     )
     re_code = re.compile(r'''vimeo\.com/(video/)?(?P<code>[0-9]+)''', re.I)
     pattern_url = 'http://player.vimeo.com/video/%s'
+    pattern_info = 'http://vimeo.com/api/v2/video/%s.json'
+
+    info = None
+
+    def init(self, url):
+        self._url = url
+        self.code = self.get_code()
+        self.info = self.get_info()
+
+        super(VimeoBackend, self).init(url)
+
+    def get_info(self):
+        try:
+            response = requests.get(self.pattern_info % self.code)
+            return json.loads(response.text)[0]
+        except ValueError:
+            raise VideoDoesntExistException()
 
     def get_thumbnail_url(self):
-        pass  # not implemented
+        return self.info['thumbnail_large']
 
 
 class SoundCloudBackend(VideoBackend):
@@ -166,7 +222,7 @@ class SoundCloudBackend(VideoBackend):
     re_code = re.compile(r'src=".*%2F(?P<code>\d+)&show_artwork.*"', re.I)
     re_url = re.compile(r'src="(?P<url>.*?)"', re.I)
 
-    def __init__(self, url):
+    def init(self, url):
         params = {
             'format': 'json',
             'url': url,
@@ -178,7 +234,7 @@ class SoundCloudBackend(VideoBackend):
         self.width = self.response.get('width')
         self.height = self.response.get('height')
 
-        super(SoundCloudBackend, self).__init__(url)
+        super(SoundCloudBackend, self).init(url)
 
     def get_thumbnail_url(self):
         return self.response.get('thumbnail_url')
